package com.boman.web.core.mapper;

import com.boman.domain.VaccineInfoOperation;

import java.util.List;

/**
 * 疫苗信息Mapper接口
 * 
 * @author ruoyi
 * @date 2021-09-05
 */
public interface VaccineInfoMapper 
{
    /**
     * 查询疫苗信息
     * 
     * @param id 疫苗信息ID
     * @return 疫苗信息
     */
    public VaccineInfoOperation selectVaccineInfoById(Long id);

    /**
     * 根据身份证号查询该信息是否存在
     * @param idCard
     * @return
     */
    public VaccineInfoOperation selectVaccineInfoByIdCard(String idCard);

    public List<VaccineInfoOperation> selectVaccineInfoByIds(Long[] ids);

    /**
     * 查询疫苗信息列表
     * 
     * @param vaccineInfo 疫苗信息
     * @return 疫苗信息集合
     */
    public List<VaccineInfoOperation> selectVaccineInfoList(VaccineInfoOperation vaccineInfo);


    public List<VaccineInfoOperation> selectVaccineInfoListByPage(int startNum, int endNum);


    /**
     * 新增疫苗信息
     * 
     * @param vaccineInfo 疫苗信息
     * @return 结果
     */
    public int insertVaccineInfo(VaccineInfoOperation vaccineInfo);

    /**
     * 修改疫苗信息
     * 
     * @param vaccineInfo 疫苗信息
     * @return 结果
     */
    public int updateVaccineInfo(VaccineInfoOperation vaccineInfo);

    int update(VaccineInfoOperation info);

    /**
     * 删除疫苗信息
     * 
     * @param id 疫苗信息ID
     * @return 结果
     */
    public int deleteVaccineInfoById(Long id);

    /**
     * 批量删除疫苗信息
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteVaccineInfoByIds(Long[] ids);

    /**
     * 根据身份证号查询用户信息
     * @param vaccineInfo
     * @return
     */
    public VaccineInfoOperation findHjInfo(VaccineInfoOperation vaccineInfo);


    /**
     * 根据dict_label 查询 dict_value
     * @param vaccineName
     * @return
     */
    public String selectSysDictDataByDictLabel(String vaccineName);

    List<VaccineInfoOperation> listByTotalTaskCnt();
}
